Struct azure_pim_cli::models::roles::RoleAssignment
source · pub struct RoleAssignment {
pub role: Role,
pub scope: Scope,
pub scope_name: String,
pub role_definition_id: String,
pub principal_id: Option<String>,
pub principal_type: Option<String>,
pub object: Option<Object>,
}Fields
role: Rolescope: Scopescope_name: Stringrole_definition_id: Stringprincipal_id: Option<String>principal_type: Option<String>object: Option<Object>Trait Implementations
sourceimpl Clone for RoleAssignment
impl Clone for RoleAssignment
sourcefn clone(&self) -> RoleAssignment
fn clone(&self) -> RoleAssignment
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for RoleAssignment
impl Debug for RoleAssignment
sourceimpl Ord for RoleAssignment
impl Ord for RoleAssignment
sourcefn cmp(&self, other: &RoleAssignment) -> Ordering
fn cmp(&self, other: &RoleAssignment) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for RoleAssignment
impl PartialEq for RoleAssignment
sourcefn eq(&self, other: &RoleAssignment) -> bool
fn eq(&self, other: &RoleAssignment) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for RoleAssignment
impl PartialOrd for RoleAssignment
sourcefn partial_cmp(&self, other: &RoleAssignment) -> Option<Ordering>
fn partial_cmp(&self, other: &RoleAssignment) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for RoleAssignment
impl Serialize for RoleAssignment
impl Eq for RoleAssignment
impl StructuralPartialEq for RoleAssignment