Struct azure_pim_cli::roles::ScopeEntry
source · pub struct ScopeEntry {
pub role: String,
pub scope: String,
pub scope_name: String,
pub role_definition_id: String,
}Fields
role: Stringscope: Stringscope_name: Stringrole_definition_id: StringTrait Implementations
sourceimpl Ord for ScopeEntry
impl Ord for ScopeEntry
sourcefn cmp(&self, other: &ScopeEntry) -> Ordering
fn cmp(&self, other: &ScopeEntry) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for ScopeEntry
impl PartialEq for ScopeEntry
sourcefn eq(&self, other: &ScopeEntry) -> bool
fn eq(&self, other: &ScopeEntry) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for ScopeEntry
impl PartialOrd for ScopeEntry
sourcefn partial_cmp(&self, other: &ScopeEntry) -> Option<Ordering>
fn partial_cmp(&self, other: &ScopeEntry) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moresourceimpl Serialize for ScopeEntry
impl Serialize for ScopeEntry
impl Eq for ScopeEntry
impl StructuralPartialEq for ScopeEntry