PimClient

Struct PimClient 

pub struct PimClient { /* private fields */ }

Implementations

Source

impl PimClient

pub fn new() -> Result<Self>

pub async fn clear_cache(&self)

pub async fn current_user(&self) -> Result<String>

pub async fn list_eligible_role_assignments( &self, scope: Option<Scope>, filter: Option<ListFilter>, ) -> Result<BTreeSet<RoleAssignment>>

List the roles available to the current user

Errors

Will return Err if the request fails or the response is not valid JSON

pub async fn list_active_role_assignments( &self, scope: Option<Scope>, filter: Option<ListFilter>, ) -> Result<BTreeSet<RoleAssignment>>

List the roles active role assignments for the current user

Errors

Will return Err if the request fails or the response is not valid JSON

pub async fn extend_role_assignment( &self, assignment: &RoleAssignment, justification: &str, duration: Duration, ) -> Result<()>

Request extending the specified role eligibility

Errors

Will return Err if the request fails or the response is not valid JSON

pub async fn activate_role_assignment( &self, assignment: &RoleAssignment, justification: &str, duration: Duration, ) -> Result<()>

Activates the specified role

Errors

Will return Err if the request fails or the response is not valid JSON

pub async fn activate_role_assignment_set( &self, assignments: &BTreeSet<RoleAssignment>, justification: &str, duration: Duration, ) -> Result<()>

pub async fn deactivate_role_assignment( &self, assignment: &RoleAssignment, ) -> Result<()>

Deactivate the specified role

Errors

Will return Err if the request fails or the response is not valid JSON

pub async fn deactivate_role_assignment_set( &self, assignments: &BTreeSet<RoleAssignment>, ) -> Result<()>

pub async fn wait_for_role_activation( &self, assignments: &BTreeSet<RoleAssignment>, wait_timeout: Duration, ) -> Result<()>

pub async fn role_assignments(&self, scope: &Scope) -> Result<Vec<Assignment>>

List role assignments

Errors

Will return Err if the request fails or the response is not valid JSON

pub async fn eligible_child_resources( &self, scope: &Scope, nested: bool, ) -> Result<BTreeSet<ChildResource>>

List eligible child resources for the specified scope

Errors

Will return Err if the request fails or the response is not valid JSON

pub async fn role_definitions(&self, scope: &Scope) -> Result<Vec<Definition>>

List role definitions available at the target scope

Note, this will cache the results for 10 minutes.

Errors

Will return Err if the request fails or the response is not valid JSON

pub async fn delete_role_assignment( &self, scope: &Scope, assignment_name: &str, ) -> Result<()>

Delete a role assignment

Errors

Will return Err if the request fails or the response is not valid JSON

pub async fn delete_eligible_role_assignment( &self, assignment: &RoleAssignment, ) -> Result<()>

Delete eligibile role assignment

This removes role assignments that are available via PIM.

Errors

Will return Err if the request fails or the response is not valid JSON

pub async fn delete_orphaned_role_assignments( &self, scope: &Scope, answer_yes: bool, nested: bool, ) -> Result<()>

pub async fn delete_orphaned_eligible_role_assignments( &self, scope: &Scope, answer_yes: bool, nested: bool, ) -> Result<()>

pub async fn activate_role_admin( &self, scope: &Scope, justification: &str, duration: Duration, ) -> Result<()>

pub async fn group_members( &self, id: &str, nested: bool, ) -> Result<BTreeSet<Object>>