Struct azure_pim_cli::PimClient
source · pub struct PimClient { /* private fields */ }Implementations
sourceimpl PimClient
impl PimClient
pub fn new() -> Result<Self>
sourcepub fn list_eligible_assignments(&self) -> Result<Assignments>
pub fn list_eligible_assignments(&self) -> Result<Assignments>
List the roles available to the current user
Errors
Will return Err if the request fails or the response is not valid JSON
sourcepub fn list_active_assignments(&self) -> Result<Assignments>
pub fn list_active_assignments(&self) -> Result<Assignments>
List the roles active role assignments for the current user
sourcepub fn activate_assignment(
&self,
principal_id: &str,
assignment: &Assignment,
justification: &str,
duration: u32,
) -> Result<Option<Uuid>>
pub fn activate_assignment( &self, principal_id: &str, assignment: &Assignment, justification: &str, duration: u32, ) -> Result<Option<Uuid>>
Activates the specified role
Errors
Will return Err if the request fails or the response is not valid JSON